From 0.7.0 to 0.8.0
===================

  ==================  =============================================
  Concerns            What happened
  ==================  =============================================
  pyasl               *New functionality*
                        - S-index into RHK conversion
                        - Convolution with Gaussian (broadGaussFast)
                        - Conversion between atomic number and
                          elemental symbol
                        - First ionization energies
                        - Conversion between decimal and
                          sexagesimal coordinates
                        - Outlier detection based on polynomial
                        - write1dFitsSpec
                        - Exponentially correlated Gaussian random
                          numbers
                        - Conversion from decimal year to gregorian
                          date
                        - Teff-color conversion
                        - Stellar age
                      *Update*
                        - Updated air-vacuum wavelength conversion
  funcFit             *New functionality*
                        - Model description
  pyaGui              *New functionality*
                        - Interactive normalization
                        - Interactive Gauss/Voigt fit
  ==================  =============================================